# MadQt
#### Tutorials and Tools for PyQt and PySide

***

MadQt is a pip package created to ease the process of using the Qt framework for python.

Qt is a powerful framework for designing Graphical User Interfaces written in c++ but
has a couple of wrappers (PyQt and PySide) that allow us to use the Python coding language.

MadQt aim is to automate and simplify many of the processes required by Qt as well
as provide custom widgets and QtDesigner plugins from and to the community.

[Get Started!](https://madponyinteractive.github.io/MadQt/get-started.html)

***

Visit our free course on [YouTube](https://youtube.com/playlist?list=PLuvCsqbtUSFAEmez6Tuyi2KitVcS4fLWX)

Support this project:

<a href="https://www.buymeacoffee.com/MadPonyInt" target="_blank">
    <img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" >
</a>


